@@ -116,7 +116,7 @@ sub set_src {
    }
    elsif ( lc $src eq 'right' ) {
       $self->{src_db_tbl} = $self->{right_db_tbl};
-      $self->{dst_db_tbl} = $self->{left_db_tbl}; 
+      $self->{dst_db_tbl} = $self->{left_db_tbl};
    }
    else {
       die "src argument must be either 'left' or 'right'"
@@ -147,7 +147,7 @@ sub dst {
 }
 
 # Sub: _take_action
-#   Call the user-provied actions.  Actions are passed an action statement
+#   Call the user-provided actions.  Actions are passed an action statement
 #   and an optional dbh.  This sub is not called directly; it's called
 #   by <change()> or <process_rows()>.
 #
@@ -164,7 +164,7 @@ sub _take_action {
 }
 
 # Sub: change
-#   Make an action SQL statment for the given parameters if not queueing.
+#   Make an action SQL statement for the given parameters if not queueing.
 #   This sub calls <_take_action()>, passing the action statement and
 #   optional dbh.  If queueing, the parameters are saved and the same work
 #   is done in <process_rows()>.  Queueing does not work with bidirectional
@@ -326,13 +326,14 @@ sub make_UPDATE {
    my $types = $self->{tbl_struct}->{type_for};
    return "UPDATE $self->{dst_db_tbl} SET "
       . join(', ', map {
+            my $is_hex = ($types->{$_} || '') =~ m/^0x[0-9a-fA-F]+$/i;
             my $is_char  = ($types->{$_} || '') =~ m/char|text|enum/i;
             my $is_float = ($types->{$_} || '') =~ m/float|double/i;
             $self->{Quoter}->quote($_)
             . '='
             .  $self->{Quoter}->quote_val(
                   $row->{$_},
-                  is_char  => $is_char,
+                  is_char  => $is_char && !$is_hex,
                   is_float => $is_float,
             );
          } grep { !$in_where{$_} } @cols)
@@ -387,7 +388,7 @@ sub make_REPLACE {
 #   A SQL statement
 sub make_row {
    my ( $self, $verb, $row, $cols ) = @_;
-   my @cols; 
+   my @cols;
    if ( my $dbh = $self->{fetch_back} ) {
       my $where = $self->make_where_clause($row, $cols);
       my $sql   = $self->make_fetch_back_query($where);
@@ -407,11 +408,12 @@ sub make_row {
       . ') VALUES ('
       . join(', ',
             map {
-               my $is_char  = ($type_for->{$_} || '') =~ m/char|text/i;
+               my $is_hex = ($type_for->{$_} || '') =~ m/^0x[0-9a-fA-F]+$/i;
+               my $is_char  = ($type_for->{$_} || '') =~ m/char|text|enum/i;
                my $is_float = ($type_for->{$_} || '') =~ m/float|double/i;
                $q->quote_val(
                      $row->{$_},
-                     is_char  => $is_char,
+                     is_char  => $is_char && !$is_hex,
                      is_float => $is_float,
                )
             } @cols)
@@ -431,18 +433,22 @@ sub make_row {
 sub make_where_clause {
    my ( $self, $row, $cols ) = @_;
    my @clauses = map {
+      my $col = $_;
+      $col = $self->{Quoter}->quote($col);
+
       my $val = $row->{$_};
       my $sep = defined $val ? '=' : ' IS ';
-      my $is_char  = ($self->{tbl_struct}->{type_for}->{$_} || '') =~ m/char|text/i;
+      my $is_char  = ($self->{tbl_struct}->{type_for}->{$_} || '') =~ m/char|text|enum/i;
       my $is_float = ($self->{tbl_struct}->{type_for}->{$_} || '') =~ m/float|double/i;
-      $self->{Quoter}->quote($_) . $sep . $self->{Quoter}->quote_val($val,
+      my $is_crc32 = ($self->{tbl_struct}->{type_for}->{$_} || '') =~ m/binary|text|blob/i;
+      $col = "CRC32($col)" if ($is_crc32);
+      $col . $sep . $self->{Quoter}->quote_val($val,
                                               is_char  => $is_char,
                                               is_float => $is_float);
    } @$cols;
    return join(' AND ', @clauses);
 }
 
-
 # Sub: get_changes
 #   Get a summary of changes made.
 #
@@ -468,7 +474,7 @@ sub get_changes {
 sub sort_cols {
    my ( $self, $row ) = @_;
    my @cols;
-   if ( $self->{tbl_struct} ) { 
+   if ( $self->{tbl_struct} ) {
       my $pos = $self->{tbl_struct}->{col_posn};
       my @not_in_tbl;
       @cols = sort {
