@@ -158,7 +158,7 @@ sub output {
 
    my $output = '';
    {
-      if ( $file ) { 
+      if ( $file ) {
          open *output_fh, '>', $file
             or die "Cannot open file $file: $OS_ERROR";
       }
@@ -600,7 +600,7 @@ sub no_diff {
 
    # diff returns 0 if there were no differences,
    # so !0 = 1 = no diff in our testing parlance.
-   $retval = $retval >> 8; 
+   $retval = $retval >> 8;
 
    if ( $retval ) {
       diag($out);
@@ -656,14 +656,15 @@ sub test_bash_tool {
 }
 
 my %checksum_result_col = (
-   ts      => 0,
-   errors  => 1,
-   diffs   => 2,
-   rows    => 3,
-   chunks  => 4,
-   skipped => 5,
-   time    => 6,
-   table   => 7,
+   ts        => 0,
+   errors    => 1,
+   diffs     => 2,
+   rows      => 3,
+   diff_rows => 4,
+   chunks    => 5,
+   skipped   => 5,
+   time      => 6,
+   table     => 7,
 );
 sub count_checksum_results {
    my ($output, $column, $table) = @_;
@@ -696,7 +697,7 @@ sub normalize_checksum_results {
    open my $fh, ">", $tmp_file or die "Cannot open $tmp_file: $OS_ERROR";
    printf $fh $output;
    close $fh;
-   my $normal_output = `cat $tmp_file | awk '/^[0-9 ]/ {print \$2 " " \$3 " " \$4 " " \$5 " " \$6 " " \$8} /^[A-Z]/ {print \$0}'`;
+   my $normal_output = `cat $tmp_file | awk '/^[0-9 ]/ {print \$2 " " \$3 " " \$4 " " \$5 " " \$6 " " \$7 " " \$9} /^[A-Z]/ {print \$0}'`;
    `rm $tmp_file >/dev/null`;
    return $normal_output;
 }
@@ -761,7 +762,7 @@ sub full_output {
 
    unlink $file;
    unlink $file2;
-   
+
    return ($output, $status);
 }
 
