@@ -25,18 +25,18 @@ import (
 )
 
 // Enable enabled the mongo profiler
-func Enable(ctx context.Context, client *mongo.Client) error {
-	res := client.Database("admin").RunCommand(ctx, primitive.M{"profile": 2})
+func Enable(ctx context.Context, client *mongo.Client, database string) error {
+	res := client.Database(database).RunCommand(ctx, primitive.M{"profile": 2})
 	return res.Err()
 }
 
 // Disable disables the mongo profiler
-func Disable(ctx context.Context, client *mongo.Client) error {
-	res := client.Database("admin").RunCommand(ctx, primitive.M{"profile": 0})
+func Disable(ctx context.Context, client *mongo.Client, database string) error {
+	res := client.Database(database).RunCommand(ctx, primitive.M{"profile": 0})
 	return res.Err()
 }
 
 // Drop drops the system.profile collection for clean up
-func Drop(ctx context.Context, client *mongo.Client) error {
-	return client.Database("").Collection("system.profile").Drop(ctx)
+func Drop(ctx context.Context, client *mongo.Client, database string) error {
+	return client.Database(database).Collection("system.profile").Drop(ctx)
 }
