@@ -3,6 +3,8 @@ package main
 import (
 	"fmt"
 	"os"
+	"os/exec"
+	"regexp"
 	"testing"
 
 	"github.com/sirupsen/logrus"
@@ -122,3 +124,18 @@ func TestCollectPerDatabaseInfo(t *testing.T) {
 		})
 	}
 }
+
+/*
+Option --version
+*/
+func TestVersionOption(t *testing.T) {
+	out, err := exec.Command("../../../bin/"+toolname, "--version").Output()
+	if err != nil {
+		t.Errorf("error executing %s --version: %s", toolname, err.Error())
+	}
+	// We are using MustCompile here, because hard-coded RE should not fail
+	re := regexp.MustCompile(toolname + `\n.*Version v?\d+\.\d+\.\d+\n`)
+	if !re.Match(out) {
+		t.Errorf("%s --version returns wrong result:\n%s", toolname, out)
+	}
+}
